@@ -37,7 +37,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <libpeasui/peas-ui-plugin-manager.h>
+#include <libpeas-gtk/peas-gtk-plugin-manager.h>
 
 #include "gedit-preferences-dialog.h"
 #include "gedit-utils.h"
@@ -45,7 +45,6 @@
 #include "gedit-document.h"
 #include "gedit-style-scheme-manager.h"
 #include "gedit-dirs.h"
-#include "gedit-plugins-engine.h"
 #include "gedit-settings.h"
 #include "gedit-utils.h"
 
@@ -416,7 +415,7 @@ on_use_default_font_changed (GSettings              *settings,
 static void
 setup_font_colors_page_font_section (GeditPreferencesDialog *dlg)
 {
-	GSettings *settings;
+	GObject *settings;
 	gboolean use_default_font;
 	gchar *system_font = NULL;
 	gchar *label;
@@ -904,14 +903,11 @@ setup_font_colors_page (GeditPreferencesDialog *dlg)
 static void
 setup_plugins_page (GeditPreferencesDialog *dlg)
 {
-	GeditPluginsEngine *engine;
 	GtkWidget *page_content;
 
 	gedit_debug (DEBUG_PREFS);
 
-	engine = gedit_plugins_engine_get_default ();
-
-	page_content = peas_ui_plugin_manager_new (PEAS_ENGINE (engine));
+	page_content = peas_gtk_plugin_manager_new ();
 	g_return_if_fail (page_content != NULL);
 
 	gtk_box_pack_start (GTK_BOX (dlg->priv->plugin_manager_place_holder),
@@ -953,7 +949,6 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 
 	gtk_window_set_title (GTK_WINDOW (dlg), _("gedit Preferences"));
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
 	/* HIG defaults */
@@ -1054,4 +1049,4 @@ gedit_show_preferences_dialog (GeditWindow *parent)
 	gtk_window_present (GTK_WINDOW (preferences_dialog));
 }
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
