@@ -376,11 +376,13 @@ activate_selected_files (GeditFileBrowserView *view)
 			g_signal_emit (view, signals[FILE_ACTIVATED], 0, &iter);
 	}
 
-	if (directory != NULL && gtk_tree_model_get_iter (view->priv->model, &iter, directory))
+	if (directory != NULL &&
+	    gtk_tree_model_get_iter (view->priv->model, &iter, directory))
+	{
 		g_signal_emit (view, signals[DIRECTORY_ACTIVATED], 0, &iter);
+	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 }
 
 static void
@@ -665,7 +667,7 @@ key_press_event (GtkWidget   *widget,
 
 	switch (event->keyval)
 	{
-		case GDK_space:
+		case GDK_KEY_space:
 			if (event->state & GDK_CONTROL_MASK)
 			{
 				handled = FALSE;
@@ -681,13 +683,13 @@ key_press_event (GtkWidget   *widget,
 			handled = TRUE;
 			break;
 
-		case GDK_Return:
-		case GDK_KP_Enter:
+		case GDK_KEY_Return:
+		case GDK_KEY_KP_Enter:
 			activate_selected_items (view);
 			handled = TRUE;
 			break;
 
-		case GDK_h:
+		case GDK_KEY_h:
 			if ((event->state & modifiers) == GDK_CONTROL_MASK)
 			{
 				toggle_hidden_filter (view);
